@@ -54,9 +54,7 @@ for k, v in loadfn(os.path.join(module_dir, "bvparam_1991.yaml")).items():
 # Read in yaml containing data-mined ICSD BV data.
 all_data = loadfn(os.path.join(module_dir, "icsd_bv.yaml"))
 ICSD_BV_DATA = {Species.from_string(sp): data for sp, data in all_data["bvsum"].items()}
-PRIOR_PROB = {
-    Species.from_string(sp): data for sp, data in all_data["occurrence"].items()
-}
+PRIOR_PROB = {Species.from_string(sp): data for sp, data in all_data["occurrence"].items()}
 
 
 def calculate_bv_sum(site, nn_list, scale_factor=1.0):
@@ -117,11 +115,7 @@ def calculate_bv_sum_unordered(site, nn_list, scale_factor=1):
                     r2 = BV_PARAMS[el2]["r"]
                     c1 = BV_PARAMS[el1]["c"]
                     c2 = BV_PARAMS[el2]["c"]
-                    R = (
-                        r1
-                        + r2
-                        - r1 * r2 * (sqrt(c1) - sqrt(c2)) ** 2 / (c1 * r1 + c2 * r2)
-                    )
+                    R = r1 + r2 - r1 * r2 * (sqrt(c1) - sqrt(c2)) ** 2 / (c1 * r1 + c2 * r2)
                     vij = exp((R - nn.nn_distance * scale_factor) / 0.31)
                     bvsum += occu1 * occu2 * vij * (1 if el1.X < el2.X else -1)
     return bvsum
@@ -187,15 +181,9 @@ class BVAnalyzer:
         self.max_permutations = max_permutations
         self.dist_scale_factor = distance_scale_factor
         self.charge_neutrality_tolerance = charge_neutrality_tolerance
-        forbidden_species = (
-            [get_el_sp(sp) for sp in forbidden_species] if forbidden_species else []
-        )
+        forbidden_species = [get_el_sp(sp) for sp in forbidden_species] if forbidden_species else []
         self.icsd_bv_data = (
-            {
-                get_el_sp(specie): data
-                for specie, data in ICSD_BV_DATA.items()
-                if specie not in forbidden_species
-            }
+            {get_el_sp(specie): data for specie, data in ICSD_BV_DATA.items() if specie not in forbidden_species}
             if len(forbidden_species) > 0
             else ICSD_BV_DATA
         )
@@ -210,11 +198,7 @@ class BVAnalyzer:
                 sigma = data["std"]
                 # Calculate posterior probability. Note that constant
                 # factors are ignored. They have no effect on the results.
-                prob[sp.oxi_state] = (
-                    exp(-((bv_sum - u) ** 2) / 2 / (sigma ** 2))
-                    / sigma
-                    * PRIOR_PROB[sp]
-                )
+                prob[sp.oxi_state] = exp(-((bv_sum - u) ** 2) / 2 / (sigma ** 2)) / sigma * PRIOR_PROB[sp]
         # Normalize the probabilities
         try:
             prob = {k: v / sum(prob.values()) for k, v in prob.items()}
@@ -223,9 +207,7 @@ class BVAnalyzer:
         return prob
 
     def _calc_site_probabilities_unordered(self, site, nn):
-        bv_sum = calculate_bv_sum_unordered(
-            site, nn, scale_factor=self.dist_scale_factor
-        )
+        bv_sum = calculate_bv_sum_unordered(site, nn, scale_factor=self.dist_scale_factor)
         prob = {}
         for specie, occu in site.species.items():
             el = specie.symbol
@@ -237,11 +219,7 @@ class BVAnalyzer:
                     sigma = data["std"]
                     # Calculate posterior probability. Note that constant
                     # factors are ignored. They have no effect on the results.
-                    prob[el][sp.oxi_state] = (
-                        exp(-((bv_sum - u) ** 2) / 2 / (sigma ** 2))
-                        / sigma
-                        * PRIOR_PROB[sp]
-                    )
+                    prob[el][sp.oxi_state] = exp(-((bv_sum - u) ** 2) / 2 / (sigma ** 2)) / sigma * PRIOR_PROB[sp]
             # Normalize the probabilities
             try:
                 prob[el] = {k: v / sum(prob[el].values()) for k, v in prob[el].items()}
@@ -281,9 +259,7 @@ class BVAnalyzer:
             equi_sites = [[site] for site in structure]
 
         # Sort the equivalent sites by decreasing electronegativity.
-        equi_sites = sorted(
-            equi_sites, key=lambda sites: -sites[0].species.average_electroneg
-        )
+        equi_sites = sorted(equi_sites, key=lambda sites: -sites[0].species.average_electroneg)
 
         # Get a list of valences and probabilities for each symmetrically
         # distinct site.
@@ -299,9 +275,7 @@ class BVAnalyzer:
                 # Sort valences in order of decreasing probability.
                 val = sorted(val, key=lambda v: -prob[v])
                 # Retain probabilities that are at least 1/100 of highest prob.
-                valences.append(
-                    list(filter(lambda v: prob[v] > 0.01 * prob[val[0]], val))
-                )
+                valences.append(list(filter(lambda v: prob[v] > 0.01 * prob[val[0]], val)))
         else:
             full_all_prob = []
             for sites in equi_sites:
@@ -320,8 +294,7 @@ class BVAnalyzer:
                     vals.append(
                         list(
                             filter(
-                                lambda v: prob[elsp.symbol][v]
-                                > 0.001 * prob[elsp.symbol][val[0]],
+                                lambda v: prob[elsp.symbol][v] > 0.001 * prob[elsp.symbol][val[0]],
                                 val,
                             )
                         )
@@ -345,9 +318,7 @@ class BVAnalyzer:
                 max_diff = max([max(v) - min(v) for v in el_oxi.values()])
                 if max_diff > 1:
                     return
-                score = functools.reduce(
-                    operator.mul, [all_prob[i][v] for i, v in enumerate(v_set)]
-                )
+                score = functools.reduce(operator.mul, [all_prob[i][v] for i, v in enumerate(v_set)])
                 if score > self._best_score:
                     self._best_vset = v_set
                     self._best_score = score
@@ -397,13 +368,13 @@ class BVAnalyzer:
                 for sp, occu in get_z_ordered_elmap(sites[0].species):
                     elements.append(sp.symbol)
                     fractions.append(occu)
-            fractions = np.array(fractions, np.float)
+            fractions = np.array(fractions, np.float_)
             new_valences = []
             for vals in valences:
                 for val in vals:
                     new_valences.append(val)
-            vmin = np.array([min(i) for i in new_valences], np.float)
-            vmax = np.array([max(i) for i in new_valences], np.float)
+            vmin = np.array([min(i) for i in new_valences], np.float_)
+            vmax = np.array([max(i) for i in new_valences], np.float_)
 
             self._n = 0
             self._best_score = 0
@@ -422,10 +393,7 @@ class BVAnalyzer:
 
                 score = functools.reduce(
                     operator.mul,
-                    [
-                        all_prob[attrib[iv]][elements[iv]][vv]
-                        for iv, vv in enumerate(v_set)
-                    ],
+                    [all_prob[attrib[iv]][elements[iv]][vv] for iv, vv in enumerate(v_set)],
                 )
                 if score > self._best_score:
                     self._best_vset = v_set
@@ -450,10 +418,7 @@ class BVAnalyzer:
                 lowest *= fractions
                 lowest = np.sum(lowest)
 
-                if (
-                    highest < -self.charge_neutrality_tolerance
-                    or lowest > self.charge_neutrality_tolerance
-                ):
+                if highest < -self.charge_neutrality_tolerance or lowest > self.charge_neutrality_tolerance:
                     self._n += 1
                     return None
 
@@ -488,9 +453,7 @@ class BVAnalyzer:
                 for site in sites:
                     assigned[site] = val
 
-            return [
-                [int(frac_site) for frac_site in assigned[site]] for site in structure
-            ]
+            return [[int(frac_site) for frac_site in assigned[site]] for site in structure]
         raise ValueError("Valences cannot be assigned!")
 
     def get_oxi_state_decorated_structure(self, structure):
@@ -551,6 +514,4 @@ def add_oxidation_state_by_site_fraction(structure, oxidation_states):
             structure[i] = new_sp
         return structure
     except IndexError:
-        raise ValueError(
-            "Oxidation state of all sites must be " "specified in the list."
-        )
+        raise ValueError("Oxidation state of all sites must be " "specified in the list.")
