@@ -6,7 +6,6 @@
 """
 This module contains the main object used to identify the coordination environments in a given structure.
 If you use this module, please cite the following:
-
 David Waroquiers, Xavier Gonze, Gian-Marco Rignanese, Cathrin Welker-Nieuwoudt, Frank Rosowski,
 Michael Goebel, Stephan Schenk, Peter Degelmann, Rute Andre, Robert Glaum, and Geoffroy Hautier,
 "Statistical analysis of coordination environments in oxides",
@@ -642,7 +641,7 @@ class LocalGeometryFinder:
             sites_indices = [
                 isite
                 for isite in sites_indices
-                if any([at in [sp.symbol for sp in self.structure[isite].species] for at in only_atoms])
+                if any(at in [sp.symbol for sp in self.structure[isite].species] for at in only_atoms)
             ]
 
         # Exclude atoms that are in the list of excluded atoms
@@ -650,7 +649,7 @@ class LocalGeometryFinder:
             sites_indices = [
                 isite
                 for isite in sites_indices
-                if not any([at in [sp.symbol for sp in self.structure[isite].species] for at in excluded_atoms])
+                if not any(at in [sp.symbol for sp in self.structure[isite].species] for at in excluded_atoms)
             ]
 
         if only_indices is not None:
@@ -1279,13 +1278,11 @@ class LocalGeometryFinder:
         """
         cn = len(self.local_geometry.coords)
         test_geometries = self.allcg.get_implemented_geometries(cn)
-        if all([cg.algorithms[0].algorithm_type == EXPLICIT_PERMUTATIONS for cg in test_geometries]):
+        if all(cg.algorithms[0].algorithm_type == EXPLICIT_PERMUTATIONS for cg in test_geometries):
             return self.get_coordination_symmetry_measures(
                 only_minimum=only_minimum, all_csms=all_csms, optimization=optimization
             )
-        if not all(
-            [all([algo.algorithm_type == SEPARATION_PLANE for algo in cg.algorithms]) for cg in test_geometries]
-        ):
+        if not all(all(algo.algorithm_type == SEPARATION_PLANE for algo in cg.algorithms) for cg in test_geometries):
             raise ValueError("All algorithms should be EXPLICIT_PERMUTATIONS or SEPARATION_PLANE")
 
         result_dict = {}
@@ -1418,7 +1415,6 @@ class LocalGeometryFinder:
         Returns the symmetry measures for a set of permutations (whose setup depends on the coordination geometry)
         for the coordination geometry "coordination_geometry". Standard implementation looking for the symmetry
         measures of each permutation
-
         :param coordination_geometry: The coordination geometry to be investigated
         :return: The symmetry measures for the given coordination geometry for each permutation investigated
         """
@@ -1604,7 +1600,6 @@ class LocalGeometryFinder:
             points_perfect: Points corresponding to the perfect geometry.
             nb_set: Neighbor set for this set of points. (used to store already computed separation planes)
             optimization: Optimization level (1 or 2).
-
         Returns:
             tuple: Continuous symmetry measures for the given coordination geometry for each plane and permutation
                    investigated, corresponding permutations, corresponding algorithms,
@@ -1706,7 +1701,7 @@ class LocalGeometryFinder:
                     s1 = [ii_sign[0] for ii_sign in outplane if ii_sign[1] < 0]
                     s2 = [ii_sign[0] for ii_sign in outplane if ii_sign[1] > 0]
                     separation = sort_separation_tuple([s1, inplane, s2])
-                    sep = tuple([len(gg) for gg in separation])
+                    sep = tuple(len(gg) for gg in separation)
                     if sep not in self.allcg.separations_cg[cn]:
                         continue
                     if sep not in nb_set.separations:
@@ -2019,7 +2014,6 @@ class LocalGeometryFinder:
         Returns the symmetry measures for a random set of permutations for the coordination geometry
         "coordination_geometry". Fallback implementation for the plane separation algorithms measures
         of each permutation
-
         :param coordination_geometry: The coordination geometry to be investigated
         :param NRANDOM: Number of random permutations to be tested
         :return: The symmetry measures for the given coordination geometry for each permutation investigated
