@@ -32,9 +32,6 @@ try:
 except ImportError:
     from scipy.misc import comb
 
-from tqdm import tqdm
-
-
 from pymatgen.analysis.phase_diagram import PDEntry, PhaseDiagram
 from pymatgen.analysis.reaction_calculator import Reaction, ReactionError
 from pymatgen.core.composition import Composition
@@ -45,6 +42,7 @@ from pymatgen.entries.computed_entries import ComputedEntry
 from pymatgen.util.coord import Simplex
 from pymatgen.util.plotting import pretty_plot
 from pymatgen.util.string import latexify
+from pymatgen.util.sequence import PBar
 
 
 __author__ = "Sai Jayaraman"
@@ -661,11 +659,11 @@ class PourbaixDiagram(MSONable):
         if nproc is not None:
             f = partial(self.process_multientry, prod_comp=tot_comp)
             with Pool(nproc) as p:
-                multi_entries = list(tqdm(p.imap(f, all_combos), total=len(all_combos)))
+                multi_entries = list(PBar(p.imap(f, all_combos), total=len(all_combos)))
             multi_entries = list(filter(bool, multi_entries))
         else:
             # Serial processing of multi-entry generation
-            for combo in tqdm(all_combos):
+            for combo in PBar(all_combos):
                 multi_entry = self.process_multientry(combo, prod_comp=tot_comp)
                 if multi_entry:
                     multi_entries.append(multi_entry)
@@ -708,7 +706,7 @@ class PourbaixDiagram(MSONable):
         if nproc is not None:
             f = partial(self.process_multientry, prod_comp=total_comp)
             with Pool(nproc) as p:
-                processed_entries = list(tqdm(p.imap(f, entry_combos), total=total))
+                processed_entries = list(PBar(p.imap(f, entry_combos), total=total))
             processed_entries = list(filter(bool, processed_entries))
         # Serial processing of multi-entry generation
         else:
@@ -751,7 +749,7 @@ class PourbaixDiagram(MSONable):
 
             # Check if reaction coeff threshold met for pourbaix compounds
             # All reactant/product coefficients must be positive nonzero
-            if all([coeff > coeff_threshold for coeff in all_coeffs]):
+            if all(coeff > coeff_threshold for coeff in all_coeffs):
                 return MultiEntry(entry_list, weights=react_coeffs)
 
             return None
