@@ -175,7 +175,7 @@ class WulffShape:
             symprec (float): for recp_operation, default is 1e-5.
         """
 
-        if any([se < 0 for se in e_surf_list]):
+        if any(se < 0 for se in e_surf_list):
             warnings.warn("Unphysical (negative) surface energy detected.")
 
         self.color_ind = list(range(len(miller_list)))
@@ -183,8 +183,8 @@ class WulffShape:
         self.input_miller_fig = [hkl_tuple_to_str(x) for x in miller_list]
         # store input data
         self.structure = Structure(lattice, ["H"], [[0, 0, 0]])
-        self.miller_list = tuple([tuple(x) for x in miller_list])
-        self.hkl_list = tuple([(x[0], x[1], x[-1]) for x in miller_list])
+        self.miller_list = tuple(tuple(x) for x in miller_list)
+        self.hkl_list = tuple((x[0], x[1], x[-1]) for x in miller_list)
         self.e_surf_list = tuple(e_surf_list)
         self.lattice = lattice
         self.symprec = symprec
@@ -244,7 +244,7 @@ class WulffShape:
 
         for i, (hkl, energy) in enumerate(zip(self.hkl_list, self.e_surf_list)):
             for op in recp_symmops:
-                miller = tuple([int(x) for x in op.operate(hkl)])
+                miller = tuple(int(x) for x in op.operate(hkl))
                 if miller not in all_hkl:
                     all_hkl.append(miller)
                     normal = recp.get_cartesian_coords(miller)
