@@ -5,8 +5,10 @@
 """
 This module contains the classes to build a ConversionElectrode.
 """
+from typing import Iterable, Dict
+from dataclasses import dataclass
 
-from monty.json import MontyDecoder
+from monty.dev import deprecated
 from scipy.constants import N_A
 
 from pymatgen.analysis.phase_diagram import PhaseDiagram
@@ -15,37 +17,37 @@ from pymatgen.apps.battery.battery_abc import AbstractElectrode, AbstractVoltage
 from pymatgen.core.composition import Composition
 from pymatgen.core.periodic_table import Element
 from pymatgen.core.units import Charge, Time
+from pymatgen.entries.computed_entries import ComputedEntry
 
 
+@dataclass
 class ConversionElectrode(AbstractElectrode):
     """
-    Class representing a ConversionElectrode.
+    Class representing a ConversionElectrode, since it is dataclass
+    this object can be constructed for the attributes.
+    However, it is usually easier to construct a ConversionElectrode using one of the classmethods
+    constructors provided.
+
+    Attribute:
+        voltage_pairs: The voltage pairs making up the Conversion Electrode.
+        working_ion_entry: A single ComputedEntry or PDEntry
+            representing the element that carries charge across the
+            battery, e.g. Li.
+        _initial_comp_formula: Starting composition for ConversionElectrode represented
+            as a string/formula.
     """
 
-    def __init__(self, voltage_pairs, working_ion_entry, initial_comp):
-        """
-        General constructor for ConversionElectrode. However, it is usually
-        easier to construct a ConversionElectrode using one of the static
-        constructors provided.
+    _initial_comp_formula: str
 
-        Args:
-            voltage_pairs: The voltage pairs making up the Conversion
-                Electrode.
-            working_ion_entry: A single ComputedEntry or PDEntry
-                representing the element that carries charge across the
-                battery, e.g. Li.
-            initial_comp: Starting composition for ConversionElectrode.
+    @property
+    def initial_comp(self) -> Composition:
         """
-        self._composition = initial_comp
-        self._working_ion_entry = working_ion_entry
-        ion_el = self._working_ion_entry.composition.elements[0]
-        self._working_ion = ion_el.symbol
-        self._vpairs = voltage_pairs
+        The pymatgen Composition representation of the initial composition
+        """
+        return Composition(self._initial_comp_formula)
 
-    @staticmethod
-    def from_composition_and_pd(
-        comp, pd, working_ion_symbol="Li", allow_unstable=False
-    ):
+    @classmethod
+    def from_composition_and_pd(cls, comp, pd, working_ion_symbol="Li", allow_unstable=False):
         """
         Convenience constructor to make a ConversionElectrode from a
         composition and a phase diagram.
@@ -71,9 +73,7 @@ class ConversionElectrode(AbstractElectrode):
                 working_ion_entry = e
 
         if not allow_unstable and not entry:
-            raise ValueError(
-                "Not stable compound found at composition {}.".format(comp)
-            )
+            raise ValueError("Not stable compound found at composition {}.".format(comp))
 
         profile = pd.get_element_profile(working_ion, comp)
         # Need to reverse because voltage goes form most charged to most
@@ -87,18 +87,30 @@ class ConversionElectrode(AbstractElectrode):
         for el, amt in comp.items():
             if el != Element(working_ion):
                 normalization_els[el] = amt
+        framework = comp.as_dict()
+        if working_ion in framework:
+            framework.pop(working_ion)
+        framework = Composition(framework)
+
         vpairs = [
             ConversionVoltagePair.from_steps(
-                profile[i], profile[i + 1], normalization_els
+                profile[i],
+                profile[i + 1],
+                normalization_els,
+                framework_formula=framework.reduced_formula,
             )
             for i in range(len(profile) - 1)
         ]
-        return ConversionElectrode(vpairs, working_ion_entry, comp)
 
-    @staticmethod
-    def from_composition_and_entries(
-        comp, entries_in_chemsys, working_ion_symbol="Li", allow_unstable=False
-    ):
+        return cls(
+            voltage_pairs=vpairs,
+            working_ion_entry=working_ion_entry,
+            _initial_comp_formula=comp.reduced_formula,
+            _framework_formula=framework.reduced_formula,
+        )
+
+    @classmethod
+    def from_composition_and_entries(cls, comp, entries_in_chemsys, working_ion_symbol="Li", allow_unstable=False):
         """
         Convenience constructor to make a ConversionElectrode from a
         composition and all entries in a chemical system.
@@ -109,11 +121,12 @@ class ConversionElectrode(AbstractElectrode):
             entries_in_chemsys: Sequence containing all entries in a
                chemical system. E.g., all Li-Fe-F containing entries.
             working_ion_symbol: Element symbol of working ion. Defaults to Li.
+            allow_unstable: If True, allow any composition to be used as the
+                    starting point of a conversion voltage curve, this is useful
+                    for comparing with insertion electrodes
         """
         pd = PhaseDiagram(entries_in_chemsys)
-        return ConversionElectrode.from_composition_and_pd(
-            comp, pd, working_ion_symbol, allow_unstable
-        )
+        return cls.from_composition_and_pd(comp, pd, working_ion_symbol, allow_unstable)
 
     def get_sub_electrodes(self, adjacent_only=True):
         """
@@ -133,53 +146,31 @@ class ConversionElectrode(AbstractElectrode):
             A list of ConversionElectrode objects
         """
 
+        # voltage_pairs = vpairs, working_ion_entry = working_ion_entry,
+        # _initial_comp_formula = comp.reduced_formula, _framework_formula = framework.reduced_formula
         if adjacent_only:
             return [
                 self.__class__(
-                    self._vpairs[i : i + 1], self._working_ion_entry, self._composition
+                    voltage_pairs=self.voltage_pairs[i : i + 1],
+                    working_ion_entry=self.working_ion_entry,
+                    _initial_comp_formula=self._initial_comp_formula,
+                    _framework_formula=self._framework_formula,
                 )
-                for i in range(len(self._vpairs))
+                for i in range(len(self.voltage_pairs))
             ]
         sub_electrodes = []
-        for i in range(len(self._vpairs)):
-            for j in range(i, len(self._vpairs)):
+        for i in range(len(self.voltage_pairs)):
+            for j in range(i, len(self.voltage_pairs)):
                 sub_electrodes.append(
                     self.__class__(
-                        self._vpairs[i : j + 1],
-                        self._working_ion_entry,
-                        self._composition,
+                        voltage_pairs=self.voltage_pairs[i : j + 1],
+                        working_ion_entry=self.working_ion_entry,
+                        _initial_comp_formula=self._initial_comp_formula,
+                        _framework_formula=self._framework_formula,
                     )
                 )
         return sub_electrodes
 
-    @property
-    def composition(self) -> Composition:
-        """
-        Returns: Composition
-        """
-        return self._composition
-
-    @property
-    def working_ion(self) -> Element:
-        """
-        The working ion as an Element object
-        """
-        return self._working_ion_entry.composition.elements[0]
-
-    @property
-    def working_ion_entry(self):
-        """
-        Returns: Working ion as an entry.
-        """
-        return self._working_ion_entry
-
-    @property
-    def voltage_pairs(self):
-        """
-        Returns: All voltage pairs.
-        """
-        return self._vpairs
-
     def is_super_electrode(self, conversion_electrode):
         """
         Checks if a particular conversion electrode is a sub electrode of the
@@ -192,16 +183,12 @@ class ConversionElectrode(AbstractElectrode):
         for pair1 in conversion_electrode:
             rxn1 = pair1.rxn
             all_formulas1 = {
-                rxn1.all_comp[i].reduced_formula
-                for i in range(len(rxn1.all_comp))
-                if abs(rxn1.coeffs[i]) > 1e-5
+                rxn1.all_comp[i].reduced_formula for i in range(len(rxn1.all_comp)) if abs(rxn1.coeffs[i]) > 1e-5
             }
             for pair2 in self:
                 rxn2 = pair2.rxn
                 all_formulas2 = {
-                    rxn2.all_comp[i].reduced_formula
-                    for i in range(len(rxn2.all_comp))
-                    if abs(rxn2.coeffs[i]) > 1e-5
+                    rxn2.all_comp[i].reduced_formula for i in range(len(rxn2.all_comp)) if abs(rxn2.coeffs[i]) > 1e-5
                 }
                 if all_formulas1 == all_formulas2:
                     break
@@ -219,16 +206,12 @@ class ConversionElectrode(AbstractElectrode):
         for pair1 in conversion_electrode:
             rxn1 = pair1.rxn
             all_formulas1 = {
-                rxn1.all_comp[i].reduced_formula
-                for i in range(len(rxn1.all_comp))
-                if abs(rxn1.coeffs[i]) > 1e-5
+                rxn1.all_comp[i].reduced_formula for i in range(len(rxn1.all_comp)) if abs(rxn1.coeffs[i]) > 1e-5
             }
             for pair2 in self:
                 rxn2 = pair2.rxn
                 all_formulas2 = {
-                    rxn2.all_comp[i].reduced_formula
-                    for i in range(len(rxn2.all_comp))
-                    if abs(rxn2.coeffs[i]) > 1e-5
+                    rxn2.all_comp[i].reduced_formula for i in range(len(rxn2.all_comp)) if abs(rxn2.coeffs[i]) > 1e-5
                 }
                 if all_formulas1 == all_formulas2:
                     break
@@ -245,7 +228,7 @@ class ConversionElectrode(AbstractElectrode):
     def __repr__(self):
         output = [
             "Conversion electrode with formula {} and nsteps {}".format(
-                self._composition.reduced_formula, self.num_steps
+                self.initial_comp.reduced_formula, self.num_steps
             ),
             "Avg voltage {} V, min voltage {} V, max voltage {} V".format(
                 self.get_average_voltage(), self.min_voltage, self.max_voltage
@@ -259,35 +242,45 @@ class ConversionElectrode(AbstractElectrode):
         ]
         return "\n".join(output)
 
-    @classmethod
-    def from_dict(cls, d):
+    def get_summary_dict(self, print_subelectrodes=True) -> Dict:
         """
+        Generate a summary dict.
+        Populates the summary dict with the basic information from the parent method then populates more information.
+        Since the parent method calls self.get_summary_dict(print_subelectrodes=True) for the subelectrodes.
+        The current methode will be called from within super().get_summary_dict.
+
         Args:
-            d (dict): Dict representation
+            print_subelectrodes: Also print data on all the possible
+                subelectrodes.
 
         Returns:
-            ConversionElectrode
+            A summary of this electrode"s properties in dict format.
         """
-        dec = MontyDecoder()
-        return cls(
-            dec.process_decoded(d["voltage_pairs"]),
-            dec.process_decoded(d["working_ion_entry"]),
-            Composition(d["initial_comp"]),
-        )
 
-    def as_dict(self):
-        """
-        Returns: MSONable dict.
-        """
-        return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
-            "voltage_pairs": [v.as_dict() for v in self._vpairs],
-            "working_ion_entry": self.working_ion_entry.as_dict(),
-            "initial_comp": self._composition.as_dict(),
-        }
+        d = super().get_summary_dict(print_subelectrodes=print_subelectrodes)
+        d["reactions"] = []
+        d["reactant_compositions"] = []
+        comps = []
+        frac = []
+        for pair in self.voltage_pairs:
+            rxn = pair.rxn
+            frac.append(pair.frac_charge)
+            frac.append(pair.frac_discharge)
+            d["reactions"].append(str(rxn))
+            for i in range(len(rxn.coeffs)):
+                if abs(rxn.coeffs[i]) > 1e-5 and rxn.all_comp[i] not in comps:
+                    comps.append(rxn.all_comp[i])
+                if abs(rxn.coeffs[i]) > 1e-5 and rxn.all_comp[i].reduced_formula != d["working_ion"]:
+                    reduced_comp = rxn.all_comp[i].reduced_composition
+                    comp_dict = reduced_comp.as_dict()
+                    d["reactant_compositions"].append(comp_dict)
+        return d
 
-    def get_summary_dict(self, print_subelectrodes=True):
+    @deprecated(
+        replacement=get_summary_dict,
+        message="Name and logic changed, will be as_dict_summary will be removed in the futurn.",
+    )
+    def as_dict_summary(self, print_subelectrodes=True):
         """
         Args:
             print_subelectrodes:
@@ -299,11 +292,7 @@ class ConversionElectrode(AbstractElectrode):
 
         d = {}
         framework_comp = Composition(
-            {
-                k: v
-                for k, v in self._composition.items()
-                if k.symbol != self.working_ion.symbol
-            }
+            {k: v for k, v in self.initial_comp.items() if k.symbol != self.working_ion.symbol}
         )
 
         d["framework"] = framework_comp.to_data_dict
@@ -324,7 +313,7 @@ class ConversionElectrode(AbstractElectrode):
         d["reactant_compositions"] = []
         comps = []
         frac = []
-        for pair in self._vpairs:
+        for pair in self.voltage_pairs:
             rxn = pair.rxn
             frac.append(pair.frac_charge)
             frac.append(pair.frac_discharge)
@@ -332,10 +321,7 @@ class ConversionElectrode(AbstractElectrode):
             for i in range(len(rxn.coeffs)):
                 if abs(rxn.coeffs[i]) > 1e-5 and rxn.all_comp[i] not in comps:
                     comps.append(rxn.all_comp[i])
-                if (
-                    abs(rxn.coeffs[i]) > 1e-5
-                    and rxn.all_comp[i].reduced_formula != d["working_ion"]
-                ):
+                if abs(rxn.coeffs[i]) > 1e-5 and rxn.all_comp[i].reduced_formula != d["working_ion"]:
                     reduced_comp = rxn.all_comp[i].reduced_composition
                     comp_dict = reduced_comp.as_dict()
                     d["reactant_compositions"].append(comp_dict)
@@ -347,69 +333,37 @@ class ConversionElectrode(AbstractElectrode):
             def f_dict(c):
                 return c.get_summary_dict(print_subelectrodes=False)
 
-            d["adj_pairs"] = list(
-                map(f_dict, self.get_sub_electrodes(adjacent_only=True))
-            )
-            d["all_pairs"] = list(
-                map(f_dict, self.get_sub_electrodes(adjacent_only=False))
-            )
+            d["adj_pairs"] = list(map(f_dict, self.get_sub_electrodes(adjacent_only=True)))
+            d["all_pairs"] = list(map(f_dict, self.get_sub_electrodes(adjacent_only=False)))
         return d
 
 
+@dataclass
 class ConversionVoltagePair(AbstractVoltagePair):
     """
     A VoltagePair representing a Conversion Reaction with a defined voltage.
     Typically not initialized directly but rather used by ConversionElectrode.
+    Attributes:
+        rxn (BalancedReaction): BalancedReaction for the step
+        voltage (float): Voltage for the step
+        mAh (float): Capacity of the step
+        vol_charge (float): Volume of charged state
+        vol_discharge (float): Volume of discharged state
+        mass_charge (float): Mass of charged state
+        mass_discharge (float): Mass of discharged state
+        frac_charge (float): Fraction of working ion in the charged state
+        frac_discharge (float): Fraction of working ion in the discharged state
+        entries_charge ([ComputedEntry]): Entries in the charged state
+        entries_discharge ([ComputedEntry]): Entries in discharged state
+        working_ion_entry (ComputedEntry): Entry of the working ion.
     """
 
-    def __init__(
-        self,
-        balanced_rxn,
-        voltage,
-        mAh,
-        vol_charge,
-        vol_discharge,
-        mass_charge,
-        mass_discharge,
-        frac_charge,
-        frac_discharge,
-        entries_charge,
-        entries_discharge,
-        working_ion_entry,
-    ):
-        """
-        Args:
-            balanced_rxn (BalancedReaction): BalancedReaction for the step
-            voltage (float): Voltage for the step
-            mAh (float): Capacity of the step
-            vol_charge (float): Volume of charged state
-            vol_discharge (float): Volume of discharged state
-            mass_charge (float): Mass of charged state
-            mass_discharge (float): Mass of discharged state
-            frac_charge (float): Fraction of working ion in the charged state
-            frac_discharge (float): Fraction of working ion in the discharged state
-            entries_charge ([ComputedEntry]): Entries in the charged state
-            entries_discharge ([ComputedEntry]): Entries in discharged state
-            working_ion_entry (ComputedEntry): Entry of the working ion.
-        """
-        self._working_ion_entry = working_ion_entry
-        working_ion = self._working_ion_entry.composition.elements[0].symbol
-        self._voltage = voltage
-        self._mAh = mAh
-        self._vol_charge = vol_charge
-        self._mass_charge = mass_charge
-        self._mass_discharge = mass_discharge
-        self._vol_discharge = vol_discharge
-        self._frac_charge = frac_charge
-        self._frac_discharge = frac_discharge
+    rxn: BalancedReaction
+    entries_charge: Iterable[ComputedEntry]
+    entries_discharge: Iterable[ComputedEntry]
 
-        self._rxn = balanced_rxn
-        self._working_ion = working_ion
-        self._entries_charge = entries_charge
-        self._entries_discharge = entries_discharge
-
-    @staticmethod
-    def from_steps(step1, step2, normalization_els):
+    @classmethod
+    def from_steps(cls, step1, step2, normalization_els, framework_formula=None):
         """
         Creates a ConversionVoltagePair from two steps in the element profile
         from a PD analysis.
@@ -423,9 +377,7 @@ class ConversionVoltagePair(AbstractVoltagePair):
         working_ion_entry = step1["element_reference"]
         working_ion = working_ion_entry.composition.elements[0].symbol
         working_ion_valence = max(Element(working_ion).oxidation_states)
-        voltage = (
-            -step1["chempot"] + working_ion_entry.energy_per_atom
-        ) / working_ion_valence
+        voltage = (-step1["chempot"] + working_ion_entry.energy_per_atom) / working_ion_valence
         mAh = (
             (step2["evolution"] - step1["evolution"])
             * Charge(1, "e").to("C")
@@ -436,18 +388,10 @@ class ConversionVoltagePair(AbstractVoltagePair):
         )
         licomp = Composition(working_ion)
         prev_rxn = step1["reaction"]
-        reactants = {
-            comp: abs(prev_rxn.get_coeff(comp))
-            for comp in prev_rxn.products
-            if comp != licomp
-        }
+        reactants = {comp: abs(prev_rxn.get_coeff(comp)) for comp in prev_rxn.products if comp != licomp}
 
         curr_rxn = step2["reaction"]
-        products = {
-            comp: abs(curr_rxn.get_coeff(comp))
-            for comp in curr_rxn.products
-            if comp != licomp
-        }
+        products = {comp: abs(curr_rxn.get_coeff(comp)) for comp in curr_rxn.products if comp != licomp}
 
         reactants[licomp] = step2["evolution"] - step1["evolution"]
 
@@ -459,13 +403,7 @@ class ConversionVoltagePair(AbstractVoltagePair):
                 break
 
         prev_mass_dischg = (
-            sum(
-                [
-                    prev_rxn.all_comp[i].weight * abs(prev_rxn.coeffs[i])
-                    for i in range(len(prev_rxn.all_comp))
-                ]
-            )
-            / 2
+            sum([prev_rxn.all_comp[i].weight * abs(prev_rxn.coeffs[i]) for i in range(len(prev_rxn.all_comp))]) / 2
         )
         vol_charge = sum(
             [
@@ -475,13 +413,7 @@ class ConversionVoltagePair(AbstractVoltagePair):
             ]
         )
         mass_discharge = (
-            sum(
-                [
-                    curr_rxn.all_comp[i].weight * abs(curr_rxn.coeffs[i])
-                    for i in range(len(curr_rxn.all_comp))
-                ]
-            )
-            / 2
+            sum([curr_rxn.all_comp[i].weight * abs(curr_rxn.coeffs[i]) for i in range(len(curr_rxn.all_comp))]) / 2
         )
         mass_charge = prev_mass_dischg
         mass_discharge = mass_discharge
@@ -509,180 +441,32 @@ class ConversionVoltagePair(AbstractVoltagePair):
         entries_charge = step2["entries"]
         entries_discharge = step1["entries"]
 
-        return ConversionVoltagePair(
-            rxn,
-            voltage,
-            mAh,
-            vol_charge,
-            vol_discharge,
-            mass_charge,
-            mass_discharge,
-            frac_charge,
-            frac_discharge,
-            entries_charge,
-            entries_discharge,
-            working_ion_entry,
+        return cls(
+            rxn=rxn,
+            voltage=voltage,
+            mAh=mAh,
+            vol_charge=vol_charge,
+            vol_discharge=vol_discharge,
+            mass_charge=mass_charge,
+            mass_discharge=mass_discharge,
+            frac_charge=frac_charge,
+            frac_discharge=frac_discharge,
+            entries_charge=entries_charge,
+            entries_discharge=entries_discharge,
+            working_ion_entry=working_ion_entry,
+            _framework_formula=framework_formula,
         )
 
-    @property
-    def working_ion(self):
-        """
-        Returns: working ion
-        """
-        return self._working_ion
-
-    @property
-    def entries_charge(self):
-        """
-        Returns: Entries pertaining to charged electrode.
-        """
-        return self._entries_charge
-
-    @property
-    def entries_discharge(self):
-        """
-        Returns: Entries pertaining to discharged electrode.
-        """
-        return self._entries_discharge
-
-    @property
-    def frac_charge(self):
-        """
-        Returns: Amount of working ion at charge
-        """
-        return self._frac_charge
-
-    @property
-    def frac_discharge(self):
-        """
-        Returns: Amount of working ion at discharge
-        """
-        return self._frac_discharge
-
-    @property
-    def rxn(self):
-        """
-        Returns: Reaction representing the conversion.
-        """
-        return self._rxn
-
-    @property
-    def voltage(self):
-        """
-        Returns: Voltage of electrode
-        """
-        return self._voltage
-
-    @property
-    def mAh(self):
-        """
-        Returns: Energy in mAh.
-        """
-        return self._mAh
-
-    @property
-    def mass_charge(self):
-        """
-        Returns: Mass of charged electrode.
-        """
-        return self._mass_charge
-
-    @property
-    def mass_discharge(self):
-        """
-        Returns: Mass of discharged electrode.
-        """
-        return self._mass_discharge
-
-    @property
-    def vol_charge(self):
-        """
-        Returns: Volume of charged electrode.
-        """
-        return self._vol_charge
-
-    @property
-    def vol_discharge(self):
-        """
-        Returns: Volume of discharged electrode.
-        """
-        return self._vol_discharge
-
-    @property
-    def working_ion_entry(self):
-        """
-        Returns: Working ion entry
-        """
-        return self._working_ion_entry
-
     def __repr__(self):
         output = [
-            "Conversion voltage pair with working ion {}".format(
-                self._working_ion_entry.composition.reduced_formula
-            ),
-            "Reaction : {}".format(self._rxn),
+            "Conversion voltage pair with working ion {}".format(self.working_ion_entry.composition.reduced_formula),
+            "Reaction : {}".format(self.rxn),
             "V = {}, mAh = {}".format(self.voltage, self.mAh),
-            "frac_charge = {}, frac_discharge = {}".format(
-                self.frac_charge, self.frac_discharge
-            ),
-            "mass_charge = {}, mass_discharge = {}".format(
-                self.mass_charge, self.mass_discharge
-            ),
-            "vol_charge = {}, vol_discharge = {}".format(
-                self.vol_charge, self.vol_discharge
-            ),
+            "frac_charge = {}, frac_discharge = {}".format(self.frac_charge, self.frac_discharge),
+            "mass_charge = {}, mass_discharge = {}".format(self.mass_charge, self.mass_discharge),
+            "vol_charge = {}, vol_discharge = {}".format(self.vol_charge, self.vol_discharge),
         ]
         return "\n".join(output)
 
     def __str__(self):
         return self.__repr__()
-
-    @classmethod
-    def from_dict(cls, d):
-        """
-        Args:
-            d (dict): Dict representation
-
-        Returns:
-            ConversionVoltagePair
-        """
-        dec = MontyDecoder()
-        working_ion_entry = dec.process_decoded(d["working_ion_entry"])
-        balanced_rxn = dec.process_decoded(d["balanced_rxn"])
-        entries_charge = dec.process_decoded(d["entries_charge"])
-        entries_discharge = dec.process_decoded(d["entries_discharge"])
-        return ConversionVoltagePair(
-            balanced_rxn,
-            d["voltage"],
-            d["mAh"],
-            d["vol_charge"],
-            d["vol_discharge"],
-            d["mass_charge"],
-            d["mass_discharge"],
-            d["frac_charge"],
-            d["frac_discharge"],
-            entries_charge,
-            entries_discharge,
-            working_ion_entry,
-        )
-
-    def as_dict(self):
-        """
-        Returns: MSONable dict
-        """
-        return {
-            "@module": self.__class__.__module__,
-            "@class": self.__class__.__name__,
-            "working_ion_entry": self._working_ion_entry.as_dict(),
-            "voltage": self._voltage,
-            "mAh": self._mAh,
-            "vol_charge": self._vol_charge,
-            "mass_charge": self._mass_charge,
-            "mass_discharge": self._mass_discharge,
-            "vol_discharge": self._vol_discharge,
-            "frac_charge": self._frac_charge,
-            "frac_discharge": self._frac_discharge,
-            "balanced_rxn": self._rxn.as_dict(),
-            "entries_charge": [e.as_dict() for e in self._entries_charge],
-            "entries_discharge": [e.as_dict() for e in self._entries_discharge],
-        }
