@@ -50,111 +50,10 @@ class ElementBase(Enum):
 
             Element symbol
 
-        .. attribute:: X
-
-            Pauling electronegativity. Elements without an electronegativity
-            number are assigned a value of zero by default.
-
-        .. attribute:: number
-
-            Alternative attribute for atomic number
-
-        .. attribute:: max_oxidation_state
-
-            Maximum oxidation state for element
-
-        .. attribute:: min_oxidation_state
-
-            Minimum oxidation state for element
-
-        .. attribute:: oxidation_states
-
-            Tuple of all known oxidation states
-
-        .. attribute:: common_oxidation_states
-
-            Tuple of all common oxidation states
-
-        .. attribute:: full_electronic_structure
-
-            Full electronic structure as tuple.
-            E.g., The electronic structure for Fe is represented as:
-            [(1, "s", 2), (2, "s", 2), (2, "p", 6), (3, "s", 2), (3, "p", 6),
-            (3, "d", 6), (4, "s", 2)]
-
-        .. attribute:: row
-
-            Returns the periodic table row of the element.
-
-        .. attribute:: group
-
-            Returns the periodic table group of the element.
-
-        .. attribute:: block
-
-            Return the block character "s,p,d,f"
-
-        .. attribute:: is_noble_gas
-
-            True if element is noble gas.
-
-        .. attribute:: is_transition_metal
-
-            True if element is a transition metal.
-
-        .. attribute:: is_post_transition_metal
-
-            True if element is a post transition metal.
-
-        .. attribute:: is_rare_earth_metal
-
-            True if element is a rare earth metal.
-
-        .. attribute:: is_metalloid
-
-            True if element is a metalloid.
-
-        .. attribute:: is_alkali
-
-            True if element is an alkali metal.
-
-        .. attribute:: is_alkaline
-
-            True if element is an alkaline earth metal (group II).
-
-        .. attribute:: is_halogen
-
-            True if element is a halogen.
-
-        .. attribute:: is_lanthanoid
-
-            True if element is a lanthanoid.
-
-        .. attribute:: is_actinoid
-
-            True if element is a actinoid.
-
-        .. attribute:: iupac_ordering
-
-            Ordering according to Table VI of "Nomenclature of Inorganic Chemistry
-            (IUPAC Recommendations 2005)". This ordering effectively follows the
-            groups and rows of the periodic table, except the Lanthanides, Actanides
-            and hydrogen.
-
         .. attribute:: long_name
 
            Long name for element. E.g., "Hydrogen".
 
-        .. attribute:: atomic_mass
-
-            Atomic mass for the element.
-
-        .. attribute:: atomic_radius
-
-            Atomic radius for the element. This is the empirical value. Data is
-            obtained from
-            http://en.wikipedia.org/wiki/Atomic_radii_of_the_elements_(data_page).
-
         .. attribute:: atomic_radius_calculated
 
             Calculated atomic radius for the element. This is the empirical value.
@@ -267,26 +166,6 @@ class ElementBase(Enum):
         .. attribute:: coefficient_of_linear_thermal_expansion
 
             Coefficient of linear thermal expansion
-
-        .. attribute:: average_ionic_radius
-
-            Average ionic radius for element in ang. The average is taken over all
-            oxidation states of the element for which data is present.
-
-        .. attribute:: average_cationic_radius
-
-            Average cationic radius for element in ang. The average is taken over all
-            positive oxidation states of the element for which data is present.
-
-        .. attribute:: average_anionic_radius
-
-            Average ionic radius for element in ang. The average is taken over all
-            negative oxidation states of the element for which data is present.
-
-        .. attribute:: ionic_radii
-
-            All ionic radii of the element as a dict of
-            {oxidation state: ionic radii}. Radii are given in ang.
         """
         self.symbol = "%s" % symbol
         d = _pt_data[symbol]
@@ -1089,8 +968,8 @@ class Species(MSONable, Stringify):
     def __init__(
         self,
         symbol: str,
-        oxidation_state: float = 0.0,
-        properties: dict = None,
+        oxidation_state: Optional[float] = 0.0,
+        properties: Optional[dict] = None,
     ):
         """
         Initializes a Species.
@@ -1188,19 +1067,20 @@ class Species(MSONable, Stringify):
 
         if self._oxi_state in self.ionic_radii:
             return self.ionic_radii[self._oxi_state]
-        d = self._el.data
-        oxstr = str(int(self._oxi_state))
-        if oxstr in d.get("Ionic radii hs", {}):
-            warnings.warn("No default ionic radius for %s. Using hs data." % self)
-            return d["Ionic radii hs"][oxstr]
-        if oxstr in d.get("Ionic radii ls", {}):
-            warnings.warn("No default ionic radius for %s. Using ls data." % self)
-            return d["Ionic radii ls"][oxstr]
+        if self._oxi_state:
+            d = self._el.data
+            oxstr = str(int(self._oxi_state))
+            if oxstr in d.get("Ionic radii hs", {}):
+                warnings.warn("No default ionic radius for %s. Using hs data." % self)
+                return d["Ionic radii hs"][oxstr]
+            if oxstr in d.get("Ionic radii ls", {}):
+                warnings.warn("No default ionic radius for %s. Using ls data." % self)
+                return d["Ionic radii ls"][oxstr]
         warnings.warn("No ionic radius for {}!".format(self))
         return None
 
     @property
-    def oxi_state(self) -> float:
+    def oxi_state(self) -> Optional[float]:
         """
         Oxidation state of Species.
         """
@@ -1435,8 +1315,8 @@ class DummySpecies(Species):
     def __init__(
         self,
         symbol: str = "X",
-        oxidation_state: float = 0,
-        properties: dict = None,
+        oxidation_state: Optional[float] = 0,
+        properties: Optional[dict] = None,
     ):
         """
         Args:
@@ -1518,7 +1398,7 @@ class DummySpecies(Species):
         return self.symbol.__hash__()
 
     @property
-    def oxi_state(self) -> float:
+    def oxi_state(self) -> Optional[float]:
         """
         Oxidation state associated with DummySpecies
         """
@@ -1583,7 +1463,7 @@ class DummySpecies(Species):
             "oxidation_state": self._oxi_state,
         }
         if self._properties:
-            d["properties"] = self._properties
+            d["properties"] = self._properties  # type: ignore
         return d
 
     @classmethod
