@@ -137,11 +137,7 @@ class PhononBandStructure(MSONable):
                         label=label,
                         coords_are_cartesian=coords_are_cartesian,
                     )
-            self.qpoints.append(
-                Kpoint(
-                    q, lattice, label=label, coords_are_cartesian=coords_are_cartesian
-                )
-            )
+            self.qpoints.append(Kpoint(q, lattice, label=label, coords_are_cartesian=coords_are_cartesian))
         self.bands = frequencies
         self.nb_bands = len(self.bands)
         self.nb_qpoints = len(self.qpoints)
@@ -151,14 +147,10 @@ class PhononBandStructure(MSONable):
         self.nac_eigendisplacements = []
         if nac_frequencies is not None:
             for t in nac_frequencies:
-                self.nac_frequencies.append(
-                    ([i / np.linalg.norm(t[0]) for i in t[0]], t[1])
-                )
+                self.nac_frequencies.append(([i / np.linalg.norm(t[0]) for i in t[0]], t[1]))
         if nac_eigendisplacements is not None:
             for t in nac_eigendisplacements:
-                self.nac_eigendisplacements.append(
-                    ([i / np.linalg.norm(t[0]) for i in t[0]], t[1])
-                )
+                self.nac_eigendisplacements.append(([i / np.linalg.norm(t[0]) for i in t[0]], t[1]))
 
     def min_freq(self):
         """
@@ -282,9 +274,7 @@ class PhononBandStructure(MSONable):
             (direction, dict(real=np.real(e).tolist(), imag=np.imag(e).tolist()))
             for direction, e in self.nac_eigendisplacements
         ]
-        d["nac_frequencies"] = [
-            (direction, f.tolist()) for direction, f in self.nac_frequencies
-        ]
+        d["nac_frequencies"] = [(direction, f.tolist()) for direction, f in self.nac_frequencies]
 
         if self.structure:
             d["structure"] = self.structure.as_dict()
@@ -298,17 +288,11 @@ class PhononBandStructure(MSONable):
         :return: PhononBandStructure
         """
         lattice_rec = Lattice(d["lattice_rec"]["matrix"])
-        eigendisplacements = (
-            np.array(d["eigendisplacements"]["real"])
-            + np.array(d["eigendisplacements"]["imag"]) * 1j
-        )
+        eigendisplacements = np.array(d["eigendisplacements"]["real"]) + np.array(d["eigendisplacements"]["imag"]) * 1j
         nac_eigendisplacements = [
-            (direction, np.array(e["real"]) + np.array(e["imag"]) * 1j)
-            for direction, e in d["nac_eigendisplacements"]
-        ]
-        nac_frequencies = [
-            (direction, np.array(f)) for direction, f in d["nac_frequencies"]
+            (direction, np.array(e["real"]) + np.array(e["imag"]) * 1j) for direction, e in d["nac_eigendisplacements"]
         ]
+        nac_frequencies = [(direction, np.array(f)) for direction, f in d["nac_frequencies"]]
         structure = Structure.from_dict(d["structure"]) if "structure" in d else None
         return cls(
             d["qpoints"],
@@ -393,10 +377,7 @@ class PhononBandStructureSymmLine(PhononBandStructure):
                 self.distance.append(previous_distance)
             else:
                 self.distance.append(
-                    np.linalg.norm(
-                        self.qpoints[i].cart_coords - previous_qpoint.cart_coords
-                    )
-                    + previous_distance
+                    np.linalg.norm(self.qpoints[i].cart_coords - previous_qpoint.cart_coords) + previous_distance
                 )
             previous_qpoint = self.qpoints[i]
             previous_distance = self.distance[i]
@@ -415,9 +396,7 @@ class PhononBandStructureSymmLine(PhononBandStructure):
                 {
                     "start_index": b[0],
                     "end_index": b[-1],
-                    "name": str(self.qpoints[b[0]].label)
-                    + "-"
-                    + str(self.qpoints[b[-1]].label),
+                    "name": str(self.qpoints[b[0]].label) + "-" + str(self.qpoints[b[-1]].label),
                 }
             )
 
@@ -431,26 +410,16 @@ class PhononBandStructureSymmLine(PhononBandStructure):
                 if np.allclose(qpoints[i], (0, 0, 0)):
                     if i > 0 and not np.allclose(qpoints[i - 1], (0, 0, 0)):
                         q_dir = self.qpoints[i - 1]
-                        direction = q_dir.frac_coords / np.linalg.norm(
-                            q_dir.frac_coords
-                        )
+                        direction = q_dir.frac_coords / np.linalg.norm(q_dir.frac_coords)
                         naf.append((direction, frequencies[:, i]))
                         if self.has_eigendisplacements:
-                            nac_eigendisplacements.append(
-                                (direction, eigendisplacements[:, i])
-                            )
-                    if i < len(qpoints) - 1 and not np.allclose(
-                        qpoints[i + 1], (0, 0, 0)
-                    ):
+                            nac_eigendisplacements.append((direction, eigendisplacements[:, i]))
+                    if i < len(qpoints) - 1 and not np.allclose(qpoints[i + 1], (0, 0, 0)):
                         q_dir = self.qpoints[i + 1]
-                        direction = q_dir.frac_coords / np.linalg.norm(
-                            q_dir.frac_coords
-                        )
+                        direction = q_dir.frac_coords / np.linalg.norm(q_dir.frac_coords)
                         naf.append((direction, frequencies[:, i]))
                         if self.has_eigendisplacements:
-                            nac_eigendisplacements.append(
-                                (direction, eigendisplacements[:, i])
-                            )
+                            nac_eigendisplacements.append((direction, eigendisplacements[:, i]))
 
             self.nac_frequencies = np.array(naf)
             self.nac_eigendisplacements = np.array(nac_eigendisplacements)
@@ -650,10 +619,7 @@ class PhononBandStructureSymmLine(PhononBandStructure):
         :return: PhononBandStructureSummLine
         """
         lattice_rec = Lattice(d["lattice_rec"]["matrix"])
-        eigendisplacements = (
-            np.array(d["eigendisplacements"]["real"])
-            + np.array(d["eigendisplacements"]["imag"]) * 1j
-        )
+        eigendisplacements = np.array(d["eigendisplacements"]["real"]) + np.array(d["eigendisplacements"]["imag"]) * 1j
         structure = Structure.from_dict(d["structure"]) if "structure" in d else None
         return cls(
             d["qpoints"],
