@@ -618,33 +618,6 @@ class StructureVis:
                 ac.GetProperty().SetOpacity(opacity)
                 ac.GetProperty().SetColor(color)
                 self.ren.AddActor(ac)
-            elif False and len(face) == 4:
-                points = vtk.vtkPoints()
-                for ii in range(4):
-                    points.InsertNextPoint(face[ii][0], face[ii][1], face[ii][2])
-                line1 = vtk.vtkLine()
-                line1.GetPointIds().SetId(0, 0)
-                line1.GetPointIds().SetId(1, 2)
-                line2 = vtk.vtkLine()
-                line2.GetPointIds().SetId(0, 3)
-                line2.GetPointIds().SetId(1, 1)
-                lines = vtk.vtkCellArray()
-                lines.InsertNextCell(line1)
-                lines.InsertNextCell(line2)
-                polydata = vtk.vtkPolyData()
-                polydata.SetPoints(points)
-                polydata.SetLines(lines)
-                ruledSurfaceFilter = vtk.vtkRuledSurfaceFilter()
-                ruledSurfaceFilter.SetInput(polydata)
-                ruledSurfaceFilter.SetResolution(15, 15)
-                ruledSurfaceFilter.SetRuledModeToResample()
-                mapper = vtk.vtkPolyDataMapper()
-                mapper.SetInput(ruledSurfaceFilter.GetOutput())
-                ac = vtk.vtkActor()
-                ac.SetMapper(mapper)
-                ac.GetProperty().SetOpacity(opacity)
-                ac.GetProperty().SetColor(color)
-                self.ren.AddActor(ac)
             elif len(face) > 3:
                 center = np.zeros(3, np.float_)
                 for site in face:
